Group: Publishing
# BEGIN SourceDeps(oneline):
BuildRequires: /usr/bin/desktop-file-install gcc-c++ swig
# END SourceDeps(oneline)
%define fedora 29
# see https://bugzilla.altlinux.org/show_bug.cgi?id=10382
%define _localstatedir %{_var}
%global majorversion 7.2

Name:           ipe
Version:        7.2.11
Release:        alt1_2
Summary:        Drawing editor for creating figures in PDF or PostScript formats
# GPLv2, with an exception for the CGAL libraries.
License:        GPLv2+ with exceptions
URL:            http://ipe.otfried.org/
Source0:	https://dl.bintray.com/otfried/generic/%{name}/%{majorversion}/%{name}-%{version}-src.tar.gz

BuildRequires:	qt5-base-devel
BuildRequires:	desktop-file-utils
BuildRequires:	lua-devel
BuildRequires:	libcairo-devel
BuildRequires:	libturbojpeg-devel
BuildRequires:	libjpeg-devel

# Tips found at https://bugzilla.redhat.com/bugzilla/show_bug.cgi?id=191589#c7
%global qtdir %(pkg-config --variable=prefix QtCore)

Requires:       tex(latex)
Requires:       urw-fonts
Requires:       xdg-utils

Provides:       ipe(api) = %{version}
Provides:       ipetoipe = %{version}
Provides:       ipetopng = %{version}
Source44: import.info

%description
Ipe is a drawing editor for creating figures in PDF or (encapsulated)
Postscript format. It supports making small figures for inclusion into
LaTeX-documents as well as making multi-page PDF presentations that
can be shown on-line with a PDF viewer


%package devel
Group: Development/Other
Summary: Development files and documentation for designing Ipelets
Requires: %{name} = %{version}-%{release}
%description devel 
This packages contains the files necessary to develop Ipelets, which are
plugins for the Ipe editor.

%package doc
Group: Documentation
BuildArch: noarch
Summary: Documentation of Ipe
Requires: %{name} = %{version}-%{release}
%description doc
%{summary}.

%prep
%setup -n %{name}-%{version} -q

# fix files permissions
find src -type f -exec chmod -x {} +

# Fix install location for lua iplets
sed -i.ipedir 's#$(IPEPREFIX)/lib/ipe/$(IPEVERS)/ipelets#$(IPELIBDIR)/ipe/$(IPEVERS)/ipelets#' src/config.mak

# remove unnecessary header
# https://github.com/otfried/ipe-issues/issues/165
sed -i '/#include <xlocale.h>/d' src/ipelib/ipeplatform.cpp

%build
export QTDIR=%{qtdir}

pushd src

for target in ipeui ipe all; do
%make_build $target \
     LUA_CFLAGS="`pkg-config --cflags lua`" \
     LUA_LIBS="`pkg-config --libs lua`" \
     MOC=moc-qt5 \
     IPEPREFIX="%{_usr}" IPELIBDIR="%{_libdir}"
done

popd 

# Create desktop file
cat > %{name}.desktop <<EOF
[Desktop Entry]
Type=Application
Encoding=UTF-8
Name=Ipe
Comment=The Ipe extensible drawing editor
Exec=ipe
Categories=Qt;Application;Graphics;
EOF

%install
pushd src
make INSTALL_ROOT=$RPM_BUILD_ROOT install \
     IPEPREFIX="%{_usr}" IPELIBDIR="%{_libdir}" \
     INSTALL_PROGRAMS="install -m 0755"
popd

# Install desktop file
desktop-file-install \
%if 0%{?fedora} && 0%{?fedora} < 19
        --vendor fedora                            \
%endif
        --dir ${RPM_BUILD_ROOT}%{_datadir}/applications         \
        --add-category X-Fedora                                 \
        %{name}.desktop



%files
%doc readme.txt gpl.txt news.txt

%{_bindir}/ipe
%{_bindir}/ipe6upgrade
%{_bindir}/ipeextract
%{_bindir}/iperender
%{_bindir}/ipescript
%{_bindir}/ipetoipe
%{_bindir}/ipepresenter

%{_libdir}/libipe.so.%{version}
%{_libdir}/libipeui.so.%{version}
%{_libdir}/libipecairo.so.%{version}
%{_libdir}/libipecanvas.so.%{version}
%{_libdir}/libipelua.so.%{version}

%dir %{_libdir}/ipe
%dir %{_libdir}/ipe/%{version}
%{_libdir}/ipe/%{version}/ipelets

%dir %{_datadir}/ipe
%dir %{_datadir}/ipe/%{version}
%{_datadir}/ipe/%{version}/icons
%{_datadir}/ipe/%{version}/lua
%{_datadir}/ipe/%{version}/styles

%{_datadir}/applications/*%{name}*.desktop

%{_mandir}/man1/ipe.1*
%{_mandir}/man1/ipe6upgrade.1*
%{_mandir}/man1/ipeextract.1*
%{_mandir}/man1/iperender.1*
%{_mandir}/man1/ipescript.1*
%{_mandir}/man1/ipetoipe.1*

%files devel
%doc readme.txt gpl.txt news.txt
%{_includedir}/*.h
%{_libdir}/libipe.so
%{_libdir}/libipeui.so
%{_libdir}/libipecairo.so
%{_libdir}/libipecanvas.so
%{_libdir}/libipelua.so

%files doc
%doc --no-dereference gpl.txt
%doc readme.txt gpl.txt news.txt
%{_datadir}/%{name}/%{version}

%changelog
* Wed Mar 13 2019 Igor Vlasenko <viy@altlinux.ru> 7.2.11-alt1_2
- update to new release by fcimport

* Fri Mar 01 2019 Igor Vlasenko <viy@altlinux.ru> 7.2.9-alt1_2
- update to new release by fcimport

* Thu Feb 07 2019 Igor Vlasenko <viy@altlinux.ru> 7.2.9-alt1_1
- update to new release by fcimport

* Wed Aug 01 2018 Igor Vlasenko <viy@altlinux.ru> 7.2.7-alt1_7
- update to new release by fcimport

* Thu Mar 08 2018 Igor Vlasenko <viy@altlinux.ru> 7.2.7-alt1_6
- update to new release by fcimport

* Wed Mar 15 2017 Igor Vlasenko <viy@altlinux.ru> 7.2.7-alt1_2
- update to new release by fcimport

* Mon Dec 19 2016 Igor Vlasenko <viy@altlinux.ru> 7.2.7-alt1_1
- update to new release by fcimport

* Thu Nov 17 2016 Igor Vlasenko <viy@altlinux.ru> 7.2.6-alt1_1
- update to new release by fcimport

* Fri Mar 08 2013 Igor Vlasenko <viy@altlinux.ru> 7.1.2-alt1_4
- update to new release by fcimport

* Mon Jan 21 2013 Igor Vlasenko <viy@altlinux.ru> 7.1.2-alt1_2
- initial fc import

